@@ -170,6 +170,8 @@ position_menu (GtkMenu *menu, gint *x, gint *y,
     GtkWidget *widget = GTK_WIDGET (user_data);
     GdkScreen *screen;
     gint twidth, theight, tx, ty;
+    GtkAllocation allocation;
+    GtkRequisition requisition;
     GtkTextDirection direction;
     GdkRectangle monitor;
     gint monitor_num;
@@ -182,31 +184,33 @@ position_menu (GtkMenu *menu, gint *x, gint *y,
 
     direction = gtk_widget_get_direction (widget);
 
-    twidth = GTK_WIDGET (menu)->requisition.width;
-    theight = GTK_WIDGET (menu)->requisition.height;
+    gtk_widget_get_requisition (GTK_WIDGET (menu), &requisition);
+    twidth = requisition.width;
+    theight = requisition.height;
 
     screen = gtk_widget_get_screen (GTK_WIDGET (menu));
-    monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
+    monitor_num = gdk_screen_get_monitor_at_window (screen, gtk_widget_get_window (widget));
     if (monitor_num < 0) monitor_num = 0;
     gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
-    if (!gdk_window_get_origin (widget->window, &tx, &ty)) {
+    if (!gdk_window_get_origin (gtk_widget_get_window (widget), &tx, &ty)) {
 	g_warning ("Menu not on screen");
 	return;
     }
 
-    tx += widget->allocation.x;
-    ty += widget->allocation.y;
+    gtk_widget_get_allocation (widget, &allocation);
+    tx += allocation.x;
+    ty += allocation.y;
 
     if (direction == GTK_TEXT_DIR_RTL)
-	tx += widget->allocation.width - twidth;
+	tx += allocation.width - twidth;
 
-    if ((ty + widget->allocation.height + theight) <= monitor.y + monitor.height)
-	ty += widget->allocation.height;
+    if ((ty + allocation.height + theight) <= monitor.y + monitor.height)
+	ty += allocation.height;
     else if ((ty - theight) >= monitor.y)
 	ty -= theight;
-    else if (monitor.y + monitor.height - (ty + widget->allocation.height) > ty)
-	ty += widget->allocation.height;
+    else if (monitor.y + monitor.height - (ty + allocation.height) > ty)
+	ty += allocation.height;
     else
 	ty -= theight;
 
@@ -311,7 +315,7 @@ drive_button_update (gpointer user_data)
     GtkIconInfo *icon_info;
     GIcon *icon;
     int width, height;
-    GdkPixbuf *pixbuf, *scaled;
+    GdkPixbuf *pixbuf = NULL, *scaled;
     GtkRequisition button_req, image_req;
     char *display_name, *tip;
 
@@ -323,8 +327,8 @@ drive_button_update (gpointer user_data)
 
     /* if no volume or mount, unset image */
     if (!self->volume && !self->mount) {
-	if (GTK_BIN (self)->child != NULL)
-	    gtk_image_set_from_pixbuf (GTK_IMAGE (GTK_BIN (self)->child), NULL);
+	if (gtk_bin_get_child (GTK_BIN (self)) != NULL)
+	    gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), NULL);
 	return FALSE;
     }
 
@@ -358,7 +362,7 @@ drive_button_update (gpointer user_data)
 
     /* base the icon size on the desired button size */
     gtk_widget_size_request (GTK_WIDGET (self), &button_req);
-    gtk_widget_size_request (GTK_BIN (self)->child, &image_req);
+    gtk_widget_size_request (gtk_bin_get_child (GTK_BIN (self)), &image_req);
     width = self->icon_size - (button_req.width - image_req.width);
     height = self->icon_size - (button_req.height - image_req.height);
 
@@ -384,7 +388,7 @@ drive_button_update (gpointer user_data)
 	pixbuf = scaled;
     }
 
-    gtk_image_set_from_pixbuf (GTK_IMAGE (GTK_BIN (self)->child), pixbuf);
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), pixbuf);
     g_object_unref (pixbuf);
 
     gtk_widget_size_request (GTK_WIDGET (self), &button_req);
@@ -551,7 +555,7 @@ open_drive (DriveButton *self, GtkWidget *item)
 						     GTK_BUTTONS_OK,
 						     _("Cannot execute '%s'"),
 						     argv[0]);
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message, NULL);
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (gtk_object_destroy), NULL);
 	gtk_widget_show (dialog);
@@ -593,6 +597,9 @@ gvm_run_command (const char *device, const char *command, const char *path)
 			g_string_append (exec, path);
 			q = p + 2;
 			p = p + 2;
+		} else {
+		        /* Ignore anything else. */
+		        p++;
 		}
 	}
 	g_string_append (exec, q);
@@ -724,7 +731,7 @@ run_command (DriveButton *self, const char *command)
 
 	mount = g_volume_get_mount (self->volume);
 	if (!mount)
-	    return FALSE;
+	    return;
 
 	file = g_mount_get_root (mount);
 	g_object_unref (mount);
@@ -765,13 +772,13 @@ unmount_drive (DriveButton *self, GtkWidget *item)
 	mount = g_volume_get_mount (self->volume);
 	if (mount)
 	{
-	    g_mount_unmount (mount, G_MOUNT_UNMOUNT_NONE,
-			     NULL, NULL, NULL);
+	    g_mount_unmount_with_operation (mount, G_MOUNT_UNMOUNT_NONE,
+	                                    NULL, NULL, NULL, NULL);
 	    g_object_unref (mount);
 	}
     } else if (self->mount) {
-	g_mount_unmount (self->mount, G_MOUNT_UNMOUNT_NONE,
-			 NULL, NULL, NULL);
+	g_mount_unmount_with_operation (self->mount, G_MOUNT_UNMOUNT_NONE,
+			                NULL, NULL, NULL, NULL);
     } else {
 	g_return_if_reached();
     }
@@ -788,22 +795,32 @@ static void
 eject_drive (DriveButton *self, GtkWidget *item)
 {
     if (self->volume) {
-	g_volume_eject (self->volume, G_MOUNT_UNMOUNT_NONE,
-			NULL, eject_finish, NULL);
+	g_volume_eject_with_operation (self->volume, G_MOUNT_UNMOUNT_NONE,
+	                               NULL, NULL,
+	                               (GAsyncReadyCallback) eject_finish,
+	                               NULL);
     } else if (self->mount) {
-	g_mount_eject (self->mount, G_MOUNT_UNMOUNT_NONE,
-		       NULL, eject_finish, NULL);
+	g_mount_eject_with_operation (self->mount, G_MOUNT_UNMOUNT_NONE,
+	                              NULL, NULL,
+	                              (GAsyncReadyCallback) eject_finish,
+	                              NULL);
     } else {
 	g_return_if_reached();
     }
 }
 static void
-play_autoplay_media (DriveButton *self, const char *autoplay_key)
+play_autoplay_media (DriveButton *self, const char *autoplay_key, 
+		     const char *dflt)
 {
 	GConfClient *gconf_client = gconf_client_get_default ();
 	char *command = gconf_client_get_string (gconf_client,
 			autoplay_key, NULL);
+
+	if (!command)
+	    command = g_strdup (dflt);
+
 	run_command (self, command);
+
 	g_free (command);
 	g_object_unref (gconf_client);
 }
@@ -811,13 +828,15 @@ play_autoplay_media (DriveButton *self, const char *autoplay_key)
 static void
 play_dvd (DriveButton *self, GtkWidget *item)
 {
-	play_autoplay_media (self, GCONF_ROOT_AUTOPLAY "autoplay_dvd_command");
+        play_autoplay_media (self, GCONF_ROOT_AUTOPLAY "autoplay_dvd_command",
+			     "totem %d");
 }
 
 static void
 play_cda (DriveButton *self, GtkWidget *item)
 {
-	play_autoplay_media (self, GCONF_ROOT_AUTOPLAY "autoplay_cda_command");
+        play_autoplay_media (self, GCONF_ROOT_AUTOPLAY "autoplay_cda_command",
+			     "sound-juicer -d %d");
 }
 
 static void
