@@ -67,8 +67,8 @@ GCONF_DIR = "/apps/invest"
 # Preload gconf directories
 #GCONF_CLIENT.add_dir(GCONF_DIR, gconf.CLIENT_PRELOAD_RECURSIVE)
 
-# tests whether the given stocks are in the old format
-def old_stock_format(stocks):
+# tests whether the given stocks are in the old labelless format
+def labelless_stock_format(stocks):
 	if len(stocks) == 0:
 		return False
 
@@ -79,8 +79,8 @@ def old_stock_format(stocks):
 	# there is no list, so it is already the new stock file format
 	return False
 
-# converts the given stocks from the old format into the new one
-def update_stock_format(stocks):
+# converts the given stocks from the labelless format into the one with labels
+def update_to_labeled_stock_format(stocks):
 	new = {}
 
 	for k, l in stocks.items():
@@ -89,15 +89,43 @@ def update_stock_format(stocks):
 
 	return new
 
+# tests whether the given stocks are in the format without exchange information
+def exchangeless_stock_format(stocks):
+	if len(stocks) == 0:
+		return False
+
+	# take the first element of the dict and check if its value is a list
+	for symbol, data in stocks.items():
+		purchases = stocks[symbol]["purchases"]
+		if len(purchases) > 0:
+			purchase = purchases[0]
+			if not purchase.has_key("exchange"):
+				return True
+
+	return False
+
+# converts the given stocks into format with exchange information
+def update_to_exchange_stock_format(stocks):
+	for symbol, data in stocks.items():
+		purchases = data["purchases"]
+		for purchase in purchases:
+			purchase["exchange"] = 0
+
+	return stocks
+
 STOCKS_FILE = join(USER_INVEST_DIR, "stocks.pickle")
 
 try:
 	STOCKS = cPickle.load(file(STOCKS_FILE))
 
-	# if the stocks file is in the old stocks format,
-	# then we need to convert it into the new format
-	if old_stock_format(STOCKS):
-		STOCKS = update_stock_format(STOCKS);
+	# if the stocks file is in the stocks format without labels,
+	# then we need to convert it into the new labeled format
+	if labelless_stock_format(STOCKS):
+		STOCKS = update_to_labeled_stock_format(STOCKS);
+
+	# if the stocks file does not contain exchange rates, add them
+	if exchangeless_stock_format(STOCKS):
+		STOCKS = update_to_exchange_stock_format(STOCKS);
 except Exception, msg:
 	error("Could not load the stocks from %s: %s" % (STOCKS_FILE, msg) )
 	STOCKS = {}
@@ -120,34 +148,66 @@ except Exception, msg:
 #	},
 #}
 
-client = gconf.client_get_default()
+CONFIG_FILE = join(USER_INVEST_DIR, "config.pickle")
+try:
+	CONFIG = cPickle.load(file(CONFIG_FILE))
+except Exception, msg:
+	CONFIG = {}       # default configuration
+
+
+# set default proxy config
+PROXY = None
 
 # borrowed from Ross Burton
 # http://burtonini.com/blog/computers/postr
+# extended by exception handling and retry scheduling
 def get_gnome_proxy(client):
-	if client.get_bool("/system/http_proxy/use_http_proxy"):
-		host = client.get_string("/system/http_proxy/host")
-		port = client.get_int("/system/http_proxy/port")
-		if host is None or host == "" or port == 0:
-			# gnome proxy is not valid, use enviroment if available
-			return None
+	sleep = 10	# sleep between attempts for 10 seconds
+	attempts = 3	# try to get configuration from gconf at most three times
+	get_gnome_proxy_retry(client, attempts, sleep)
 
-		if client.get_bool("/system/http_proxy/use_authentication"):
-			user = client.get_string("/system/http_proxy/authentication_user")
-			password = client.get_string("/system/http_proxy/authentication_password")
-			if user and user != "":
-				url = "http://%s:%s@%s:%d" % (user, password, host, port)
+def get_gnome_proxy_retry(client, attempts, sleep):
+	# decrease attempts counter
+	attempts -= 1
+
+	# sanity check if we still need to look for proxy configuration
+	global PROXY
+	if PROXY != None:
+		return
+
+	# try to get config from gconfd
+	try:
+		if client.get_bool("/system/http_proxy/use_http_proxy"):
+			host = client.get_string("/system/http_proxy/host")
+			port = client.get_int("/system/http_proxy/port")
+			if host is None or host == "" or port == 0:
+				# gnome proxy is not valid, stop here
+				return
+
+			if client.get_bool("/system/http_proxy/use_authentication"):
+				user = client.get_string("/system/http_proxy/authentication_user")
+				password = client.get_string("/system/http_proxy/authentication_password")
+				if user and user != "":
+					url = "http://%s:%s@%s:%d" % (user, password, host, port)
+				else:
+					url = "http://%s:%d" % (host, port)
 			else:
 				url = "http://%s:%d" % (host, port)
-		else:
-			url = "http://%s:%d" % (host, port)
 
-		return {'http': url}
-	else:
-		# gnome proxy is not set, use enviroment if available
-		return None
+			# proxy config found, memorize
+			PROXY = {'http': url}
+
+	except Exception, msg:
+		error("Failed to get proxy configuration from GConfd:\n%s" % msg)
+		# we did not succeed, schedule retry
+		if attempts > 0:
+			error("Retrying to contact GConfd in %d seconds" % sleep)
+			gobject.timeout_add(sleep * 1000, get_gnome_proxy_retry, client, attempts, sleep)
+
+# use gconf to get proxy config
+client = gconf.client_get_default()
+get_gnome_proxy(client)
 
-PROXY = get_gnome_proxy(client)
 
 # connect to Network Manager to identify current network connectivity
 nm = networkmanager.NetworkManager()
