@@ -22,8 +22,6 @@
 #include <config.h>
 #include <string.h>
 
-#include <libgnome/gnome-exec.h>
-
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
@@ -36,7 +34,7 @@
 
 #define KEY_AUDIBLE_BELL "/apps/metacity/general/audible_bell"
 
-void beep (void);
+static void beep (void);
 
 void
 mc_exec_command (MCData     *mc,
@@ -74,7 +72,7 @@ mc_exec_command (MCData     *mc,
 		g_free (str);
 	} else {
 		gtk_entry_set_text (GTK_ENTRY (mc->entry), (gchar *) "");
-		append_history_entry (mc, cmd, FALSE);	
+		append_history_entry (mc, cmd, FALSE);
 		}
 	g_strfreev (argv);
 
@@ -82,11 +80,11 @@ mc_exec_command (MCData     *mc,
 		g_error_free (error);
 }
 
-void beep (void)
+static void beep (void)
 {
 	GConfClient *default_client;
 	gboolean audible_bell_set;
-	
+
 	default_client = gconf_client_get_default ();
 	audible_bell_set = gconf_client_get_bool (default_client, KEY_AUDIBLE_BELL, NULL);
 	if (audible_bell_set) {
